# frozen_string_literal: true

require 'active_model'
require 'uri'

module Yade
  module Composer
    module Rest
      # model
      module Model
        # Project
        class ComposerProject
          include ActiveModel::Model
          include ActiveModel::Validations
          include ActiveModel::Serializers::JSON
          include Yade::Common::Config

          attr_accessor :id, :name, :gitUrl

          validates_presence_of 'id', 'name', 'gitUrl'

          def attributes
            instance_values
          end

          def install_dir
            "#{ComposerConfig[:composer_home]}/#{name}"
          end

          def installed?
            File.directory?("#{ComposerConfig[:composer_home]}/#{name}")
          end

          def uninstall
            FileUtils.rm_rf("#{ComposerConfig[:composer_home]}/#{name}")
          end

          def git_repo_name
            uri = URI(gitUrl)

            uri.path.split('/').last.split('.').first
          end
        end

      end
    end
  end
end
